@@ -4,5 +4,3 @@
 # https://github/dpploy/covid-surge
 
 from .src.covid_surge_main import Surge
-from .src.help import color_map
-from .src.help import filename
