@@ -9,8 +9,6 @@ Global COVID-19 surge period analysis.
 Expand on this later.
 '''
 
-import numpy as np
-
 from covid_surge import Surge
 
 def main():
@@ -51,7 +49,6 @@ def main():
 
     for (sort_key,data) in fit_data:
         country = data[0]
-        param_vec = data[3]
         key = g_surge.get_bin_id(sort_key,bins)
         if key in country_groups:
             country_groups[key].append(country)
